---
# Feel free to add content and custom Front Matter to this file.
# To modify the layout, see https://jekyllrb.com/docs/themes/#overriding-theme-defaults

layout: home
---

*sltoo* extends [rmtoo](http://rmtoo.florath.net/)—a text based requirements
tracking tool—with traceability features and Excel import and export. It's a
CLI tool that will generate PDF outputs amongst other.

## Who

Engineering teams that need to collect and track requirements with a low
barrier to entry and means to communicate with non-technical stakeholders.

Teams that need to follow a document driven development process, e.g.,
[V-Model](https://en.wikipedia.org/wiki/V-Model_(software_development)).

## Why

* Manage requirements
* Create traceability
* Store everything in human-readable text files.
    * and track them with your version-control of choice

## Key Features

* Requirements shipped with code
    * Including relational meta-information
* Traceability matrix automated
    * Continuously updated documentation
* Document Versioning (baselining)

## Getting Started

Download the example [Excel sheet](https://kown7.github.io/pymergevcd/assets/requirements/artifacts/specification.xlsx)
and modify to your needs.

After a first iteration, download the [template project ZIP file](https://kown7.github.io/pymergevcd/assets/template_project.zip), 
copy the previous Excel sheet to the import folder and run the`./run.sh`. See
the proposed [workflow](_posts/2021-02-06-workflow.md).


### Demo

The reference implementation is used a demonstration: <https://kown7.github.io/pymergevcd/>

The generated documents are the
[architecture specification](https://kown7.github.io/pymergevcd/#architecture)
and 
[requirement specification](https://kown7.github.io/pymergevcd/#requirements).
See [Reference
Implementation](_posts/2021-09-06-swissed21.md#reference-implementation).

